@@ -171,7 +171,7 @@ class TestClickReviewUrlDispatcher(cr_tests.TestClickReview):
                                      key="domain-suffix",
                                      value="example.com")
         self.set_test_url_dispatcher(self.default_appname,
-                                     key="domain-suffix",
+                                     key="nonexistent",
                                      value="example.com",
                                      append=True)
         c = ClickReviewUrlDispatcher(self.test_name)
@@ -216,13 +216,12 @@ class TestClickReviewUrlDispatcher(cr_tests.TestClickReview):
                                      key="protocol",
                                      value="some-protocol")
         c = ClickReviewUrlDispatcher(self.test_name)
-        print(c.manifest["hooks"])
 
         # create a new hooks database for our peer hooks tests
         tmp = dict()
 
         # add our hook
-        tmp["url-dispatcher"] = \
+        tmp["urls"] = \
             self.test_manifest["hooks"][self.default_appname]["urls"]
 
         # update the manifest and test_manifest
